Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Flag ¶
type Flag struct {
Key string `toml:"key"`
Env string `toml:"env,omitempty"`
Message string `toml:"message"`
ValueType string `toml:"value_type"`
DefaultValue interface{} `toml:"default_value"`
ParsedValue interface{} `toml:"-"`
}
Flag is used to unmarshal the JSON
type Flags ¶
type Flags struct {
Flags []*Flag `toml:"flags"`
}
Flags is only used to parse the toml
type Flonfig ¶
Flonfig is the core of this package
func (*Flonfig) ImplementData ¶
func (*Flonfig) ImplementFile ¶
Implement will load the config file if the target file exists or read it as config string if the target file does not exist and implement it as flags
Click to show internal directories.
Click to hide internal directories.